/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Michael Hashimoto
 */
public class CommitFactory {

	public static Commit newCommit(
		String gitLogEntity, GitWorkingDirectory gitWorkingDirectory) {

		Matcher matcher = _pattern.matcher(gitLogEntity);

		if (!matcher.matches()) {
			throw new RuntimeException("Unable to find Git SHA");
		}

		String message = matcher.group("message");
		String sha = matcher.group("sha");
		Commit.Type type = Commit.Type.MANUAL;

		if (message.startsWith("archive:ignore")) {
			type = Commit.Type.LEGACY_ARCHIVE;
		}

		return new BaseCommit(gitWorkingDirectory, message, sha, type);
	}

	private static final Pattern _pattern = Pattern.compile(
		"(?<sha>[0-9a-f]{40}) (?<message>.*)");

}