/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.IOException;

import org.json.JSONObject;

/**
 * @author Michael Hashimoto
 */
public class JenkinsSlave {

	public JenkinsSlave(JenkinsMaster jenkinsMaster, String slaveName) {
		_jenkinsMaster = jenkinsMaster;
		_slaveName = slaveName;

		_localURL = JenkinsResultsParserUtil.combine(
			"http://", _jenkinsMaster.getName(), "/computer/", _slaveName, "/");
	}

	public JenkinsMaster getJenkinsMaster() {
		return _jenkinsMaster;
	}

	public String getName() {
		return _slaveName;
	}

	public boolean isOffline() throws IOException {
		JSONObject jsonObject = JenkinsResultsParserUtil.toJSONObject(
			_localURL + "api/json?tree=offline");

		return jsonObject.getBoolean("offline");
	}

	public void takeSlavesOffline(String offlineReason) {
		_setSlaveStatus(offlineReason, true);
	}

	public void takeSlavesOnline(String offlineReason) {
		_setSlaveStatus(offlineReason, false);
	}

	private void _setSlaveStatus(String offlineReason, boolean offlineStatus) {
		try {
			String script = "script=";

			Class<?> clazz = JenkinsSlave.class;

			script += JenkinsResultsParserUtil.readInputStream(
				clazz.getResourceAsStream(
					"dependencies/set-slave-status.groovy"));

			script = script.replace("${slaves}", _slaveName);
			script = script.replace(
				"${offline.reason}",
				offlineReason.replaceAll("\n", "<br />\\\\n"));
			script = script.replace(
				"${offline.status}", String.valueOf(offlineStatus));

			JenkinsResultsParserUtil.executeJenkinsScript(
				_jenkinsMaster.getName(), script);
		}
		catch (IOException ioe) {
			System.out.println(
				"Unable to set the status for slaves: " + _slaveName);

			ioe.printStackTrace();
		}
	}

	private final JenkinsMaster _jenkinsMaster;
	private final String _localURL;
	private final String _slaveName;

}